.. :changelog:

Release History
---------------

1.0.9 (2016-01-01)
------------------

**Privacyfixes**

- Fix scan_file (upload to VT), do not leak full path. (credit: @Rafiot)

1.0.8 (2014-12-26)
------------------

**Bugfixes**

- Fixed get_url_report method for the Private API (credit: @John-Lin)

1.0.7 (2014-10-17)
------------------

**Bugfixes**

- Fixed get_network_traffic method to return the pcap data (credit: adrianherrera)

1.0.6 (2014-09-22)
------------------

**Bugfixes**

- Fixed a small typo in the private API's scan_file method (credit: adrianherrera)

1.0.5 (2014-05-18)
------------------

**Bugfixes**

- Fixing README.rst for better PYPI presentation.

1.0.2 (2014-05-18)
------------------

**API Changes**

- Changing folder structure so when people import it it is not dumb :(

1.0.1 (2014-04-14)
------------------

**Bugfixes**

- Trying to fix setup.py for deploying to PYPI.
